@@ -367,9 +367,9 @@ static void handle_click(struct swaybar_sni *sni, struct swaybar_output *output,
 		method = "ContextMenu";
 	}
 
-	if (sni->menu && strcmp(method, "ContextMenu") == 0) {
-		if (!sni->tray->menu) {
-			swaybar_dbusmenu_create(sni, output, seat, serial, x, y);
+	if (strcmp(method, "ContextMenu") == 0) {
+		if (sni->menu && !sni->tray->menu) {
+			swaybar_dbusmenu_open(sni, output, seat, serial, x, y);
 		}
 	} else if (strncmp(method, "Scroll", strlen("Scroll")) == 0) {
 		char dir = method[strlen("Scroll")];
@@ -391,14 +391,19 @@ static int cmp_sni_id(const void *item, const void *cmp_to) {
 
 static enum hotspot_event_handling icon_hotspot_callback(
 		struct swaybar_output *output, struct swaybar_hotspot *hotspot,
-		struct swaybar_seat *seat, uint32_t serial, double x, double y,
-		uint32_t button, void *data) {
+		struct swaybar_seat *seat, uint32_t serial,
+		double x, double y, uint32_t button, bool released, void *data) {
 	sway_log(SWAY_DEBUG, "Clicked on %s", (char *)data);
 
 	struct swaybar_tray *tray = output->bar->tray;
 	int idx = list_seq_find(tray->items, cmp_sni_id, data);
 
 	if (idx != -1) {
+		if (released) {
+			// Since we handle the pressed event, also handle the released event
+			// to block it from falling through to a binding in the bar
+			return HOTSPOT_IGNORE;
+		}
 		struct swaybar_sni *sni = tray->items->items[idx];
 		// guess global position since wayland doesn't expose it
 		struct swaybar_config *config = tray->bar->config;
@@ -474,6 +479,11 @@ uint32_t render_sni(cairo_t *cairo, struct swaybar_output *output, double *x,
 		sni->target_size = target_size;
 	}
 
+	// Passive
+	if (sni->status && sni->status[0] == 'P') {
+		return 0;
+	}
+
 	int icon_size;
 	cairo_surface_t *icon;
 	if (sni->icon) {
